@@ -1,4 +1,4 @@
-/* $Id: cpu.h,v 1.30 2005/06/07 09:54:43 bdejean Exp $ */
+/* $Id: cpu.h,v 1.31 2005/12/09 16:15:44 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -52,8 +52,11 @@ G_BEGIN_DECLS
 
 #define GLIBTOP_MAX_CPU		18
 
-/* Nobody should really be using more than 4 processors. */
-#define GLIBTOP_NCPU		4
+/* Nobody should really be using more than 4 processors.
+   Yes we are :)
+   Nobody should really be using more than 32 processors.
+*/
+#define GLIBTOP_NCPU		32
 
 typedef struct _glibtop_cpu	glibtop_cpu;
 
