@@ -1,4 +1,4 @@
-/* $Id: shm_limits.h,v 1.24 2004/12/06 14:44:10 bdejean Exp $ */
+/* $Id: shm_limits.h,v 1.25 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -49,7 +49,7 @@ struct _glibtop_shm_limits
 		shmall;		/* GLIBTOP_IPC_SHMALL	*/
 };
 
-#define glibtop_get_shm_limits(shm)	glibtop_get_shm_limits_l(glibtop_global_server, shm)
+void glibtop_get_shm_limits(glibtop_shm_limits *buf);
 
 #if GLIBTOP_SUID_SHM_LIMITS
 #define glibtop_get_shm_limits_r	glibtop_get_shm_limits_p
